@@ -2,7 +2,7 @@
     function (x, ...) 
 {
     cat("\nPermutation test for a CCA/RDA call:\n")
-    cat(deparse(x$Call), "\n\n")
+    cat(deparse(x$call), "\n\n")
     Pval <- sum(x$F.perm >= x$F.0)/x$nperm
     cat("Test for significance of all constrained eigenvalues\n")
     cat("Pseudo-F:\t", x$F.0, "\n")
